<?PHP
/**
 * Constains lists for grouping marking types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out marking types.
 */
final class MDConcMarkingType {

    const MARKING_TYPES_VERBOSE = [

        # Handwriting

        "handschrifltich" => "handwritten",
        "handschriflich" => "handwritten",
        "handschriftlich" => "handwritten",
        "handschriftlich, Kleber" => "handwritten",
        "roter wasserfester Stift" => "handwritten",
        "keine Inschrift" => "handwritten",
        "geschrieben" => "handwritten",
        "Ölpastellstift geschrieben" => "handwritten",
        "mit Ölpastellstift geschrieben" => "handwritten",
        "geschrieben mit schwarzer Ölfarbe" => "handwritten",
        "geschrieben mit schwarzer Farbe" => "handwritten",
        "mit schwarzem Stift geschrieben" => "handwritten",
        "mit Tusche auf Holz geschrieben" => "handwritten",
        "mit Tinte geschrieben" => "handwritten",

        "mit gelben Klebepunkten" => "handwritten",
        "handschriftlich + geklebt" => "handwritten",
        "Einkreisung mit wasserfestem Marker" => "handwritten",
        "mit Bleistift geschrieben" => "handwritten",
        "Federtusche" => "handwritten",
        "schwarz geschrieben und glasiert" => "handwritten",
        "mit Farbe geschrieben" => "handwritten",
        "eingeschrieben" => "handwritten",

        # Scratchings
        "kratzen, Filzstift" => "scratch",
        "gekratzt" => "scratch",
        "eingeritztes Kreuzchen" => "scratch",
        "eingekratzt" => "scratch",

        # Glued
        "aufgeklebter Druck" => "glued",
        "Aufkleber" => "glued",
        "aufgeklebt" => "glued",
        "geklebt" => "glued",
        "Aufkleber weiß, rechteckig" => "glued",
        "Papieraufkleber" => "glued",
        "Abziehbild" => "glued",

        "Etikett" => "glued",   // This whole value doesn't make sense

        # Cast (e.g. iron cast)
        "Guss" => "cast",
        "Guß" => "cast",
        "gegossen" => "cast",
        "eingegossen" => "cast",
        "mit eingegossen" => "cast",

        # Printed
        "Druck" => "overprint",
        "gedruckt" => "overprint",
        "bedruckt" => "overprint",
        "aufgedruckt" => "overprint",
        "Tiefdruck" => "overprint",
        "Tiefdruck, weiß" => "overprint",
        "Aufdruck" => "overprint",
        "eingedruckt" => "overprint",
        "mit schwarzer Farbe bedruckt" => "overprint",
        "Druck und glasiert" => "overprint",
        "Druck, weiße Schrift" => "overprint",
        "schwarzer Aufdruck" => "overprint",
        "schwwarzer Aufdruck" => "overprint",
        "geplottert" => "overprint",

        # Sewn
        "genäht" => "sewn",
        "aufgenäht" => "sewn",
        "bestickter viereckiger Aufnäher" => "sewn",
        "gestickt/genäht" => "sewn",
        "gedruckt/genäht" => "sewn",
        "maschinell gestickt bzw. aufgenähr" => "sewn",
        "maschinell gestickt bzw. aufgenäht" => "sewn",

        # Burnt in
        "eingebrannt" => "burnt_in",
        "Brandstempel" => "burnt_in",
        "Brennstempel" => "burnt_in",

        # Stamped
        "stamped" => "stamp",
        "gestempelt" => "stamp",
        "schwarz gestempelt" => "stamp",
        "blauer Stempel" => "stamp",
        "roter Stempel" => "stamp",
        "Eichstempel" => "stamp",
        "mit Metallstempel eingedrückt" => "stamp",

        # Engraving
        "Gravur" => "engraving",
        "graviert" => "engraving",
        "eingraviert" => "engraving",
        "aufgraviert" => "engraving",
        "graviert und gestempelt" => "engraving",

        # Screwed on
        "angeschraubt" => "screwed",
        "aufgeschraubt" => "screwed",
        "Schild aufgeschraubt" => "screwed",
        "Schild angeschraubt" => "screwed",
        "Messingschild angeschraubt" => "screwed",
        "Schild" => "screwed",
        "Herstellerschild" => "screwed",
        "Bleischild" => "screwed", # Kind of unclear
        "Messingschild" => "screwed",
        "Typenschild" => "screwed",
        "Blechschild" => "screwed",
        "Plaste-/Firmenschild" => "screwed",
        "ovales Messingschild" => "screwed",
        "ovales Blechschild (schwarz/silbern)" => "screwed",
        "ovales Messingschild, rot/silbern" => "screwed",

        # Riveted
        "Angenietet" => "riveted",
        "Metallschild angenietet" => "riveted",

        # Embossing
        "geprägt" => "embossing",
        "eingeprägt" => "embossing",
        "Prägung" => "embossing",
        "Stempel eingeprägt" => "embossing",
        "geflechelt" => "embossing",
        "schwarze Prägung" => "embossing",
        "aufgesetzt und genutet, eingeprägt" => "embossing",
        "geprägt im ovalen Stempel" => "embossing",
        "eingeprägt/gegossen" => "embossing",
        "Marke mit Stempel eingeschlagen" => "embossing",
        "geprägt auf Schleife" => "embossing",
        "eingeprägt, Umschrift um mittiges Löwen-Wappentier" => "embossing",
        "3 Marken mit Stempel eingeschlagen" => "embossing",
        "3 gleiche Marken mit Stempel nebeneinander eingeschlagen" => "embossing",
        "Marken mit Stempel eingeschlagen" => "embossing",

        # Embroidery
        "gestickt" => "embroidered",
        "bestickt" => "embroidered",
        "maschinell gestickt" => "embroidered",
        "mit Goldfaden bestickt" => "embroidered",

        # Punched
        "gestanzt" => "punched",
        "eingestanzt" => "punched",

        # Scarified
        "geritzt" => "scarified",
        "eingeritzt" => "scarified",

        # Hallmarked
        "gepunzt" => "hallmarked",
        "eingepunzt" => "hallmarked",
        "gepunzt/gestanzt" => "hallmarked",
        "punziert" => "hallmarked",

        # Nailed
        "genagelt" => "nailed",
        "angenagelt" => "nailed",
        "eingenagelt" => "nailed",

        # Signature
        "signiert" => "signature",
        "farbig bemalt und glasiert" => "signature",
        "gemalt und glasiert" => "signature",

    ];

}
